@@ -86,7 +86,7 @@
 #define KCMUTILS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCMUTILS_NO_DEPRECATED
-#  define KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55400
+#  define KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55500
 #endif
 #ifdef KCMUTILS_NO_DEPRECATED_WARNINGS
 #  define KCMUTILS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCMUTILS_DEPRECATED_WARNINGS_SINCE KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCMUTILS_DEPRECATED_WARNINGS_SINCE 0x55400
+#    define KCMUTILS_DEPRECATED_WARNINGS_SINCE 0x55500
 #  endif
 #endif
 
@@ -127,6 +127,12 @@
 #else
 #  define KCMUTILS_DEPRECATED_VERSION_5_82(text)
 #endif
+
+#if KCMUTILS_DEPRECATED_WARNINGS_SINCE >= 0x55500
+#  define KCMUTILS_DEPRECATED_VERSION_5_85(text) KCMUTILS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCMUTILS_DEPRECATED_VERSION_5_85(text)
+#endif
 #define KCMUTILS_DEPRECATED_VERSION_5(minor, text)      KCMUTILS_DEPRECATED_VERSION_5_##minor(text)
 #define KCMUTILS_DEPRECATED_VERSION(major, minor, text) KCMUTILS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KCMUTILS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCMUTILS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -192,7 +198,7 @@
 #define KCMUTILS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCMUTILS_NO_DEPRECATED
-#  define KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55400
+#  define KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55500
 #endif
 #ifdef KCMUTILS_NO_DEPRECATED_WARNINGS
 #  define KCMUTILS_DEPRECATED_WARNINGS_SINCE 0
@@ -202,7 +208,7 @@
 #  ifdef KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCMUTILS_DEPRECATED_WARNINGS_SINCE KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCMUTILS_DEPRECATED_WARNINGS_SINCE 0x55400
+#    define KCMUTILS_DEPRECATED_WARNINGS_SINCE 0x55500
 #  endif
 #endif
 
@@ -233,6 +239,12 @@
 #else
 #  define KCMUTILS_DEPRECATED_VERSION_5_82(text)
 #endif
+
+#if KCMUTILS_DEPRECATED_WARNINGS_SINCE >= 0x55500
+#  define KCMUTILS_DEPRECATED_VERSION_5_85(text) KCMUTILS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCMUTILS_DEPRECATED_VERSION_5_85(text)
+#endif
 #define KCMUTILS_DEPRECATED_VERSION_5(minor, text)      KCMUTILS_DEPRECATED_VERSION_5_##minor(text)
 #define KCMUTILS_DEPRECATED_VERSION(major, minor, text) KCMUTILS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KCMUTILS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCMUTILS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
